@@ -79,7 +79,7 @@ class InputData:
                     sparse_pauli_operator
                 )
                 self.data["operator"] = {
-                    "pauli_terms": pauli_terms,
+                    "pauli-terms": pauli_terms,
                     "coefficients": coefficients,
                 }
             elif label == "pub":
@@ -361,6 +361,10 @@ In case the service has been recently started please wait 5 minutes for it to be
             )
             if status_code == 201:
                 return Job(result["id"])
+            elif status_code == 401:
+                print(
+                    "You are not authorized to access this service. Please try to authenticate first."
+                )
             else:
                 print(
                     f"Job submission has failed with http status code: {status_code}. \nRemote server response: '{result}'"
@@ -420,6 +424,10 @@ In case the service has been recently started please wait 5 minutes for it to be
             )
             if status_code == 201:
                 return WorkflowJob(result["id"])
+            elif status_code == 401:
+                print(
+                    "You are not authorized to access this service. Please try to authenticate first."
+                )
             else:
                 print(
                     f"Workflow job submission has failed with http status code: {status_code}. \nRemote server response: '{result}'"
